#library(geomtextpath)
library(psych)
library(haven)
library(ggplot2)
library(tidyr)
library(dplyr)

#Function to create original PCA from UKBB MNI data
#FYI, not of use for individual GWAS projects

setwd("/home/fbeyer/UKBB/ukbb-spatial-wmh/analysis") #/data/pt_life_whm/Analysis/ukbb-spatial-wmh/analysis") #"/home/fbeyer/UKBB/ukbb-spatial-wmh/analysis")

datadir="/isilon/cbib/INSERM_U897/Frauke/ukbb/mni" #where data are located on isilon server

source("create_bullseye_df.R")
source("create_PCA.R")

#### LOAD individual Bullseye WM data ####
results_weight=create_bullseye(location=datadir, "_mean_WMHweight.txt", scale_TIV=FALSE)
colnames(results_weight[[2]])[3]="average"

results_volume=create_bullseye(location=datadir, "_volume_WMH.txt", scale_TIV=FALSE)
colnames(results_volume[[2]])[3]="vol"

res=list(results_weight, results_volume)
#save(res, file=paste0(datadir, "res_UKBB_weight_volume_N4737.Rdata"))

load(paste0(datadir, "res_UKBB_weight_volume_N4737.Rdata"))
### Merge weight & volume
resmni=merge(res[[1]][[2]], res[[2]][[2]], all.x=T, by=c("pseudonym", "region", "depth"))                 

resmni=resmni %>%mutate(sumWMH=vol*average)

colnames(resmni)[4]="bullseye_c"
write.csv(resmni, paste0(datadir, "res_UKBB_long_MNI_wmhvol_N4737.csv"))

### Perform PCA on TIV-scaled WMH volumes

resmni=read.csv(paste0(datadir, "res_UKBB_long_MNI_wmhvol_N4737.csv"))

pca_UKBB_MNI=create_PCA(resmni, dep="sumWMH", method="pca",nfactors = 4, 
                    rotation="oblimin")


save(pca_UKBB_MNI, file="ukbb_pca_mni_4comp_N4737.Rdata")

#Check adequate dimension of components (6 are selected)
fa.parallel(pca_UKBB_MNI[[1]],cor="cov",fa = "pc",n.obs=length(unique(resmni$pseudonym)))

## Add demographics 
demographics=read.csv("/isilon/cbib/INSERM_U897/UKBiobank_data/UKBiobank2023_App94113/PhenotypeData/Proteomic/Proteomic_Data.txt.tab", sep="\t")
demographics$pseudonym=paste0("sub-", demographics$f.eid)


resmni=read.csv(paste0(datadir, "res_UKBB_long_MNI_wmhvol_N4737.csv"))

resmni=merge(resmni, demographics, by="pseudonym", all.x=T)

#f.21003.0.0 = Age at MRI

resmni65=resmni[resmni$f.21003.0.0>=65, ]

pca_UKBB_MNI_65=create_PCA(resmni65, dep="sumWMH", method="pca",nfactors = 3, 
                    rotation="oblimin")

fa.parallel(pca_UKBB_MNI_65[[1]],cor="cov",fa = "pc",n.obs=length(unique(resmni65$pseudonym)))


# PREPARE Plotting of components
data.princip=pca_UKBB_MNI_65[[2]] #pca_UKBB_MNI[[2]]
nfactors=3 #4 for all, 3 for >=65y
tmp=data.princip$loadings
tmp2=as.data.frame(tmp[,c(seq(1:nfactors))])
tmp2$regions=row.names(tmp2)

l_oblimin=tmp2%>%
  pivot_longer(cols=seq(1:nfactors),names_to = "comp", values_to = "loadings")
#add NA loadings to occipital_rh_1
for (hemi in c("lh", "rh")){
  for (i in seq(1:nfactors)){
l_oblimin = rbind(l_oblimin, c(paste0("occipital_",hemi,"_1"), paste0("TC",i), NA))
}}

l_oblimin$region=rep(factor(c("BG","BG","BG","BG", "frontal_lh", "frontal_lh", "frontal_lh", "frontal_lh",
"frontal_rh","frontal_rh","frontal_rh","frontal_rh", "occipital_lh","occipital_lh","occipital_lh",
"occipital_rh","occipital_rh","occipital_rh","parietal_lh","parietal_lh","parietal_lh","parietal_lh",
   "parietal_rh","parietal_rh","parietal_rh","parietal_rh",
  "temporal_lh","temporal_lh","temporal_lh","temporal_lh",
  "temporal_rh","temporal_rh","temporal_rh","temporal_rh", 
  "occipital_lh", "occipital_rh"),
                      levels = c("frontal_rh", "temporal_rh", "parietal_rh",
                                 "occipital_rh", "BG", "occipital_lh", "parietal_lh",
                                 "temporal_lh", "frontal_lh")),each=nfactors) 
#rename regions for plotting
l_oblimin$shell=rep(factor(c("1", "2", "3", "4",
"1", "2", "3", "4",
"1", "2", "3", "4",
"2", "3", "4", 
"2", "3", "4", 
"1", "2", "3", "4",
"1", "2", "3", "4",
"1", "2", "3", "4",
"1", "2", "3", "4", 
"1","1"), levels=c("1", "2", "3", "4")), each=nfactors)


varexpl=round(data.princip$Vaccounted["Proportion Explained",], 2)
labnames=as_labeller(c("TC1" = paste0("TC1 (", varexpl["TC1"],")"),
                       "TC2" = paste0("TC2 (", varexpl["TC2"],")"),
                       "TC3" = paste0("TC3 (", varexpl["TC3"],")"),
                       "TC4" = paste0("TC4 (", varexpl["TC4"],")"),
                       "TC5" = paste0("TC5 (", varexpl["TC5"],")"),
                       "TC6" = paste0("TC6 (", varexpl["TC6"],")"),
                       "TC7" = paste0("TC7 (", varexpl["TC7"],")")))

plotlist=list(labnames,l_oblimin)
save(plotlist, file="ukbb_l_oblimin_mni_65y.Rdata")

#FOR PLOTTING ON MPI SERVER
## for MPI server
load("ukbb_l_oblimin_mni.Rdata")
load("ukbb_l_oblimin_mni_65y.Rdata")
p2=ggplot(l_oblimin, aes(x = region, y =shell)) +
  geom_tile(aes(fill=loadings),
            color = "gray25",
            lwd = 0.4,
            linetype = 1)+
  coord_curvedpolar(theta= "x")+
  scale_fill_gradient(low = "white", high = "red") +
  #annotate(geom="text",label="City1", y=0.1, x=0.1)+
  facet_wrap(~comp,ncol = ceiling(nfactors/2), labeller = labnames) +
  theme_bw() +
  theme(panel.border = element_blank(),
        axis.text.x = element_text(size=8,
                                   colour = "black", vjust = 0.05),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.text.y = element_blank(),
        legend.position = "none",
        panel.grid.major = element_blank(),
        strip.text.x = element_text(size = 10,
                                    margin = margin( b = 1, t = 1)),
        panel.spacing.x = unit(0.5, "lines"),
        plot.margin=grid::unit(c(0,0,0,0), "mm"))

# ggsave(p2,
#        file=paste0("Bullseye_UKBB_individual_N5917_comp4.png"),
#        width = 10, height=10, unit="cm")