#library(geomtextpath)
library(psych)
library(haven)
library(ggplot2)
library(tidyr)
library(dplyr)
#Function to create original PCA from UKBB data
#FYI, not of use for individual GWAS projects

setwd("/data/pt_life_whm/Analysis/ukbb-spatial-wmh/analysis") #"/home/fbeyer/UKBB/ukbb-spatial-wmh/analysis")

#datadir="/isilon/cbib/INSERM_U897/Frauke/ukbb/data/" #where data are located on isilon server

source("create_bullseye_df.R")
source("create_PCA.R")

#### LOAD individual Bullseye WM data ####
results=create_bullseye(location=datadir, "res_sum.txt", scale_TIV=TRUE)
write.csv(results[[1]], paste0(datadir, "res_UKBB_cross_individual_N5719.csv"))
write.csv(results[[2]], paste0(datadir, "res_UKBB_cross_individual_N5719.csv"))

results=create_bullseye(location=datadir, "res_sum.txt", scale_TIV=FALSE)
res_long=results[[2]]
write.csv(results[[1]], paste0(datadir, "res_UKBB_cross_individual_scaleN_N5719.csv"))
write.csv(results[[2]], paste0(datadir, "res_UKBB_long_individual_scaleN_N5719.csv"))

### Perform PCA on TIV-scaled WMH volumes
res_long=read.csv("../res_UKBB_long_individual_N5719.csv")

res_long$asinhWMH = asinh(res_long[, "WMH_vol_adj"])
rescross=res_long[, c("pseudonym","asinhWMH", "bullseye_c")]%>%
  pivot_wider(id_cols=pseudonym, names_from=bullseye_c, values_from=asinhWMH)%>%
  mutate_at(.vars = c(2:37), ~(scale(.) %>% as.vector))
  
corr_matrix <- cor(rescross[,c(2:37)],use = "complete.obs")

#Perform PCA
nfactors=6
data.princip=psych::principal(rescross[,c(2:37)], 
                              nfactors=nfactors, 
                              scores=TRUE,
                              rotate="oblimin")
save(data.princip, file="ukbb_pca.Rdata")

#Check adequate dimension of components (6 are selected)
fa.parallel(corr_matrix,cor="cov",fa = "pc",n.obs=length(unique(rescross$pseudonym)))

#Adjust WMH volume for WM volume
### LOAD individual Bullseye WM vol####
bevol=create_bullseye(location=datadir, "res_be_vol.txt", scale_TIV=FALSE)

bevol_cross=bevol[[1]]
colnames(bevol_cross)[c(1:41)]=paste0(colnames(bevol_cross)[c(1:41)], "_vol")
bevol_long=bevol[[2]]
colnames(bevol_long)[8]=paste0(colnames(bevol_long)[8], "_vol")

res_long_ns=read.csv(paste0(datadir, "/res_UKBB_long_individual_scaleN_N5719.csv"))

merged=merge(res_long_ns[, c("pseudonym", "bullseye_c", "region", "depth", "val")], 
            bevol_long[, c("pseudonym", "region", "depth", "val_vol")], 
            all.x=T, by=c("pseudonym", "region", "depth"))

merged=merged %>% mutate(rel_wmh_vol=val/val_vol,
                        asinhWMH = asinh(rel_wmh_vol))

merged$asinhWMH = asinh(merged[, "rel_wmh_vol"])
write.csv(merged, paste0(datadir, "res_UKBB_long_individual_normalized_N5719.csv"))

rescross=merged[, c("pseudonym","asinhWMH", "bullseye_c")]%>%
  pivot_wider(id_cols=pseudonym, names_from=bullseye_c, values_from=asinhWMH)%>%
  mutate_at(.vars = c(2:37), ~(scale(.) %>% as.vector))
  
corr_matrix <- cor(rescross[,c(2:37)],use = "complete.obs")

#Perform PCA
nfactors=5
data.princip=psych::principal(rescross[,c(2:37)], 
                              nfactors=nfactors, 
                              scores=TRUE,
                              rotate="oblimin")
save(data.princip, file="ukbb_pca_relwmh.Rdata")

#Check adequate dimension of components (5 are selected)
fa.parallel(corr_matrix,cor="cov",fa = "pc",n.obs=length(unique(rescross$pseudonym)))

# #Plotting of components
tmp=data.princip$loadings
tmp2=as.data.frame(tmp[,c(seq(1:nfactors))])
tmp2$regions=row.names(tmp2)

l_oblimin=tmp2%>%
  pivot_longer(cols=seq(1:nfactors),names_to = "comp", values_to = "loadings")
l_oblimin$region=factor(rep(unique(res_long$region),each=nfactors*4), levels=c("frontal_lh", "temporal_lh", "parietal_lh", "occipital_lh",
                                                                           "BG", "occipital_rh", "parietal_rh", "temporal_rh", "frontal_rh" ))
#rename regions for plotting
l_oblimin$shell=rep(unique(res_long$depth),each=nfactors,9)

varexpl=round(data.princip$Vaccounted["Proportion Explained",], 2)
labnames=as_labeller(c("TC1" = paste0("TC1 (", varexpl["TC1"],")"),
                       "TC2" = paste0("TC2 (", varexpl["TC2"],")"),
                       "TC3" = paste0("TC3 (", varexpl["TC3"],")"),
                       "TC4" = paste0("TC4 (", varexpl["TC4"],")"),
                       "TC5" = paste0("TC5 (", varexpl["TC5"],")"),
                       "TC6" = paste0("TC6 (", varexpl["TC6"],")"),
                       "TC7" = paste0("TC7 (", varexpl["TC7"],")")))

p2=ggplot(l_oblimin, aes(x = region, y =shell)) +
  geom_tile(aes(fill=loadings),
            color = "gray25",
            lwd = 0.4,
            linetype = 1)+
  coord_curvedpolar(theta= "x")+
  scale_fill_gradient(low = "white", high = "red") +
  #annotate(geom="text",label="City1", y=0.1, x=0.1)+
  facet_wrap(~comp,ncol = ceiling(nfactors/2), labeller = labnames) +
  theme_bw() +
  theme(panel.border = element_blank(),
        axis.text.x = element_text(size=8,
                                   colour = "black", vjust = 0.05),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.text.y = element_blank(),
        legend.position = "none",
        panel.grid.major = element_blank(),
        strip.text.x = element_text(size = 10,
                                    margin = margin( b = 1, t = 1)),
        panel.spacing.x = unit(0.5, "lines"),
        plot.margin=grid::unit(c(0,0,0,0), "mm"))

# ggsave(p2,
#        file=paste0("Bullseye_UKBB_individual_N5917_comp4.png"),
#        width = 10, height=10, unit="cm")
