library(dplyr)
library(ggplot2)
library(geomtextpath )
library(readODS)
library(tidyr)
library(stringr)
library(psych)
library(BayesFactor)
library(mice)
library(performance)
library(forcats)
library(tidyverse)

#prepare sample
res=read.table(paste0("/data/pt_life_whm/Data/UKBB/res_bullseye_WMH.txt"), 
               fill = T)
#cut every second column
res=res[,c(seq(1,ncol(res),2))]
res$subj=seq(1,nrow(res))

#bring into longformat
reslong = res %>% pivot_longer(cols=V1:V71, values_to = "WMH")

regions=read.table("/data/pt_life_whm/Analysis/UKBB_spatialWMH/lookuptable_bullseye_MNIatlas.txt")
colnames(regions)=c("roi_value", "name")
regions$region=factor(unlist(str_split(regions$name, 'h_'))[seq(1,72,2)],
                     levels = c("frontal_r", "temporal_r", "parietal_r",
                                "occipital_r", "BG_", "occipital_l", "parietal_l",
                                "temporal_l", "frontal_l"))
levels(regions$region)=c("frontal_rh", "temporal_rh", "parietal_rh",
                         "occipital_rh", "BG", "occipital_lh", "parietal_lh",
                         "temporal_lh", "frontal_lh")
regions$shell=factor(unlist(str_split(regions$name, 'h_'))[seq(2,72,2)],
                      levels=c("4", "3", "2","1"))


#create factors in correct order for plotting
reslong$region=rep(regions$region, nrow(res))
reslong$depth=rep(regions$shell, nrow(res))
reslong$name=paste0(reslong$region,'_',reslong$depth)
reslong$depth_be=factor(rep(regions$shell, nrow(res)),
                     levels=c("1", "2", "3", "4"))

res_UKBB_cross=reslong[, c("subj","WMH", "name")]%>%
  pivot_wider(id_cols=subj, names_from=name, values_from=WMH)%>%
  dplyr::select(subj, BG_1, BG_2, BG_3,BG_4,
        frontal_lh_1,frontal_lh_2,frontal_lh_3,frontal_lh_4,
        occipital_lh_1,occipital_lh_2,occipital_lh_3,occipital_lh_4,
        temporal_lh_1,temporal_lh_2,temporal_lh_3,temporal_lh_4,
        parietal_lh_1,parietal_lh_2,parietal_lh_3,parietal_lh_4, 
        frontal_rh_1,frontal_rh_2,frontal_rh_3,frontal_rh_4,
        occipital_rh_1,occipital_rh_2,occipital_rh_3,occipital_rh_4,
        temporal_rh_1,temporal_rh_2,temporal_rh_3,temporal_rh_4,
        parietal_rh_1,parietal_rh_2,parietal_rh_3,parietal_rh_4)

write.csv(res_UKBB_cross, "/data/pt_life_whm/Results/multivariate_cSVD/bullseye/UKBB/res_UKBB_cross.csv",
          row.names=F)

##to have same order as for other BE results
res_long_true=res_UKBB_cross%>%
  pivot_longer(cols=2:37, names_to = "bullseye_c", values_to="WMH")
regions=factor(rep(c("BG", "frontal_lh", "occipital_lh", "temporal_lh", "parietal_lh", "frontal_rh", "occipital_rh", "temporal_rh", "parietal_rh"),
                   each=4),
               levels = c("frontal_rh", "temporal_rh", "parietal_rh",
                          "occipital_rh", "BG", "occipital_lh", "parietal_lh",
                          "temporal_lh", "frontal_lh"))
depth=rep(c("1","2","3","4"),9)
res_long_true$region=rep(regions,length(unique(res_long_true$subj)))
res_long_true$depth=rep(depth,length(unique(res_long_true$subj)))


#MERGE with demographic data
#res=merge(res, sample[c("pseudonym", "Age_all", "sex", "waist2hip", "hypertension_composite_score", "EstimatedTotalIntraCranialVol")], by.x="subj", by.y="pseudonym")

#The individual parcellations are adjusted for TIV by the formula from the paper
#meanTIV=mean(sample$EstimatedTotalIntraCranialVol)
#res = res %>% mutate(WMH_vol_adj=WMH_vol*meanTIV/EstimatedTotalIntraCranialVol)

ggplot(reslong,aes(WMH, fill=shell))+
  geom_histogram(bins=30)+
  facet_grid(.~region)+  #wrap(nrow = 9, ncol=4, vars(region))+  xlim(0,xmax) +
  xlab("WMH in mm³") +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))
ggsave(paste0("/data/pt_life_whm/Data/UKBB/UKBB_MNImask_histogram_all",xmax,".jpg"), width = 14, height=10)

xmax=5000
ggplot(reslong[reslong$WMH>10,],aes(WMH, fill=shell))+
  geom_histogram(bins=30)+
  facet_grid(.~region)+  #wrap(nrow = 9, ncol=4, vars(region))+ 
  xlim(0,xmax) +
  ylim(0,50000)+
  xlab("WMH in mm³") +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1))
ggsave(paste0("/data/pt_life_whm/Data/UKBB/UKBB_MNImask_histogram_WMH_10mm3",xmax,".jpg"), width = 14, height=10)


ggplot(reslong[reslong$region=="occipital_lh"|reslong$region=="occipital_rh",],aes(WMH, fill=shell))+
  geom_histogram(bins=30)+
  facet_grid(.~region)

##summarise data for repeating plot from paper
res_sum = reslong %>% group_by(region,shell_be) %>% summarise(med_vol_adj=median(WMH))

ggplot(res_sum, aes(x = region, y =shell_be)) +
  geom_tile(aes(fill=med_vol_adj),
            color = "gray50",
            lwd = 0.3,
            linetype = 1)+
  coord_curvedpolar(theta= "x")+
  scale_fill_gradient(low = "white", high = "red") +
  theme_bw() +
  theme(panel.border = element_blank(),
        axis.text.x = element_text(size = 14),
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        axis.ticks.y=element_blank(),
        axis.text.y = element_blank(),
        panel.grid.major = element_blank())


ggsave("/data/pt_life_whm/Data/UKBB/UKBB_MNImask_histogram.jpg", width = 14, height=10)


##TRY PCA
source("/data/pt_life_whm/Analysis/multivariate_risk_svd/LIFE/bullseye/individual_space/create_bullseye_plot.R")
source("/data/pt_life_whm/Analysis/multivariate_risk_svd/LIFE/bullseye/individual_space/create_PCA.R")

colnames(res_long_true)[1]=c("pseudonym")

#check scree plot
fa.parallel(pca_UKBB[[1]],fa = "pc", n.obs=length(unique(res_long_true$pseudonym)))

pca_UKBB=create_PCA(res_long_true, dep="WMH", method="pca",nfactors = 5, rotation="none")
ggsave(pca_UKBB[[3]],file="/data/tu_fbeyer/myDocuments/Results/multivariate_risk_svd/Results/UKBB/figures/Bullseye_UKBB.png",
       width = 40, height=20)


## Some other packages for determining number of components etc.

#library(factoextra)
#fviz_eig(, addlabels = TRUE)
#ggsave("/data/pt_life_whm/Data/UKBB/UKBB_skreeplot.jpg")

#install.packages("paran")
#install.packages("relimp")
library(relimp, pos = 4)
library(paran)
#this results in 2 components
paran(pca_UKBB[[1]], iterations = 5000, centile = 0, quietly = FALSE, 
      status = TRUE, all = TRUE, cfa = TRUE, graph = TRUE, color = TRUE, 
      col = c("black", "red", "blue"), lty = c(1, 2, 3), lwd = 1, legend = TRUE, 
      file = "", width = 640, height = 640, grdevice = "png", seed = 0)


#plot results
#fviz_pca_var(data.pca, col.var = "cos2",
#             gradient.cols = c("black", "orange", "green"),
#             repel = TRUE)


